-- BEGIN COPYRIGHT
-- *************************************************************************
-- Licensed Materials - Property of IBM 
-- 5724-L01, 5655-N53, 5724-I82, 5655-R15
-- (C) Copyright IBM Corporation 2005, 2006. All rights reserved. 
-- US Government Users Restricted Rights - Use, duplication, or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- *************************************************************************
-- END COPYRIGHT
--

-- *******************************************
-- Create dynamic artifact repository tables
-- for Oracle
-- *******************************************


-- *******************************************
-- Create the BYTESTORE table
-- *******************************************

CREATE TABLE BYTESTORE
  (ARTIFACTTNS VARCHAR2(250) NOT NULL,
   ARTIFACTNAME VARCHAR2(200) NOT NULL,
   ARTIFACTTYPE VARCHAR2(50) NOT NULL,
   INITIALBYTES BLOB,
   TIMESTAMP1 NUMBER(19) NOT NULL,
   FILENAME VARCHAR2(250),
   BACKINGCLASS VARCHAR2(250),
   CHARENCODING VARCHAR2(50),
   APPNAME VARCHAR2(200),
   COMPONENTTNS VARCHAR2(250),
   COMPONENTNAME VARCHAR2(200),
   SCAMODULENAME VARCHAR2(200),
   SCACOMPONENTNAME VARCHAR2(200));

ALTER TABLE BYTESTORE
  ADD CONSTRAINT PK_BYTESTORE PRIMARY KEY (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME);

CREATE INDEX BYTESTORE_INDEX1 ON BYTESTORE (
      COMPONENTTNS,
      COMPONENTNAME);

CREATE INDEX BYTESTORE_INDEX2 ON BYTESTORE (
      ARTIFACTTYPE,
      COMPONENTTNS,
      COMPONENTNAME);


-- *******************************************
-- Create the BYTESTOREOVERFLOW table
-- *******************************************

CREATE TABLE BYTESTOREOVERFLOW
  (ARTIFACTTYPE VARCHAR2(50) NOT NULL,
   ARTIFACTTNS VARCHAR2(250) NOT NULL,
   ARTIFACTNAME VARCHAR2(200) NOT NULL,
   SEQUENCENUMBER NUMBER(10) NOT NULL,
   BYTES BLOB);

ALTER TABLE BYTESTOREOVERFLOW
  ADD CONSTRAINT PK_BYTESTOREOVERFL PRIMARY KEY (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME, SEQUENCENUMBER);


-- *******************************************
-- Create the APPTIMESTAMP table
-- *******************************************

CREATE TABLE APPTIMESTAMP
  (APPNAME VARCHAR2(200) NOT NULL,
   TIMESTAMP1 NUMBER(19) NOT NULL);

ALTER TABLE APPTIMESTAMP
  ADD CONSTRAINT PK_APPTIMESTAMP PRIMARY KEY (APPNAME);

-- *******************************************
-- Create the CUSTPROPERTIES table
-- *******************************************

CREATE TABLE CUSTPROPERTIES
  (PROPERTYID VARCHAR (128) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   PNAME VARCHAR(250) NOT NULL,
   PVALUE VARCHAR(250) NOT NULL,
   PTYPE VARCHAR (16) NOT NULL);

ALTER TABLE CUSTPROPERTIES
  ADD CONSTRAINT PK_CUSTPROPERTIES PRIMARY KEY (PROPERTYID);

CREATE INDEX CUSTPROPERTIES_INDEX1 ON CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS);  
      
CREATE INDEX CUSTPROPERTIES_INDEX2 ON CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTNAME);
  
CREATE INDEX CUSTPROPERTIES_INDEX3 ON CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS,
      ARTIFACTNAME);  
      
CREATE INDEX CUSTPROPERTIES_INDEX4 ON CUSTPROPERTIES (
      ARTIFACTTYPE,
      PNAME);      
      
CREATE INDEX CUSTPROPERTIES_INDEX5 ON CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS,
      PNAME);      